/*
	File:		CodecLibrary.h

	Contains:	Graphics library for QuickTime decompression of QuickDraw GX
				data.

				This library uses QuickTime compression and decompression to
				image QuickDraw GX data. The basic technique is to encapsulate
				the QuickDraw GX image in a compressed data format using the
				object flattening functions from QuickDraw GX. Once the
				compressed image data is created, it may be passed to the
				QuickDraw GX codec and drawn using the QuickTime image
				compression functions or embedded within a QuickDraw picture
				and drawn using the DrawPicture function. In either case, the
				compressed data is passed to the the low-level QuickDraw
				drawing routines through the StdPix bottleneck routine. StdPix
				decompresses the data using the QuickDraw GX codec and passes
				the decompressed data to the bitsProc bottleneck routine when
				rendering the image.

	Written by:	Mike Reed

	Copyright:	 1995-1997 by Apple Computer, Inc., all rights reserved.

	Writers:

		(jtd)	John Daggett
		(DH)	David Hayward
		(IK)	Ingrid Kelly

	Change History (most recent first):

		 <5>	  6/1/97	IK		Modify printing routines for GXGraphics 1.1.6.
		 <4>	  4/8/97	DH		Minor fix.
		 <3>	  2/6/97	DH		Added ShapeToPICTWithShape.
		 <2>	 9/14/95	jtd		Replaced boolean with Boolean.
		 <1>	 9/14/95	jtd		First checked in.
*/

#ifndef __CODECLIBRARY__
#define __CODECLIBRARY__

#ifndef __EVENTS__
#include <Events.h>
#endif

#ifndef __GXTYPES__
#include <GXTypes.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

extern Handle		GXCdShapeToHandle(gxShape source, PicHandle proxie, Boolean forPrintingOnly, Boolean eraseBackground);
extern PicHandle	GXCdShapeToPicture(gxShape theShape, PicHandle proxie, Fixed hScale, Fixed vScale, Boolean forPrintingOnly, Boolean eraseBackground);
extern void			GXCdDrawShape(gxShape theShape, PicHandle proxie, Fixed hScale, Fixed vScale, Boolean forPrintingOnly, Boolean eraseBackground);
extern PicHandle	GXCdShapeToBitmap(gxShape source);
extern void			GXCdShapeToScrap(gxShape source, Boolean addProxie, Boolean forPrintingOnly, Boolean eraseBackground);
extern void			GXCdDragAndDropShape(EventRecord* event, gxShape shape);

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#ifdef __cplusplus
}
#endif

#endif /* __CODECLIBRARY__ */
