/*
	File:		StorageLibrary.h

	Contains:	Graphics library for primitive flattening of QuickDraw GX data.

	Written by:	Cary Clark, Georgiann Delaney, Michael Fairman, Dave Good, Robert Johnson, Keith McGreggor, Oliver Steele, David Van Brink, Chris Yerga

	Copyright:	 1995-1997 by Apple Computer, Inc., all rights reserved.

	Writers:

		(jtd)	John Daggett
		(DH)	David Hayward
		(IK)	Ingrid Kelly

	Change History (most recent first):

		 <4>	  6/1/97	IK		Modify printing routines for GXGraphics 1.1.6.
		 <3>	  4/8/97	DH		Added ShapeToFSSpec and FSSpecToShape.
		 <2>	  5/1/95	jtd		Bringing in final 1.1 source changes.
		 <1>	  1/9/95	jtd		First checked in.
*/

#ifndef __STORAGELIBRARY__
#define __STORAGELIBRARY__

#ifndef __FILES__
#include <Files.h>
#endif

#ifndef __GXTYPES__
#include <GXTypes.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

/* For compatibility with old headers. */
#define storageLibraryIncludes

struct userSpool {
	gxSpoolBlock	spool;
	long			reference;
	long			position;
	long			size;
	void			*data;
	void			*userField;
};
typedef struct userSpool userSpool;

extern Handle	GXStShapeToHandle(gxShape source);
extern Handle	GXStShapeToHandleWithFlags(gxShape source, gxFlattenFlag flags);
extern gxShape	GXStHandleToShape(Handle target, long count, const gxViewPort portList[]);
extern void		GXStShapeToFRef(gxShape source, short fileRef);
extern gxShape	GXStFRefToShape(short fileRef, long count, const gxViewPort portList[]);
extern void		GXStShapeToFile(gxShape source, Str255 fileName, short vRefNum, OSType creator, OSType fileType);
extern gxShape	GXStFileToShape(Str255 fileName, short vRefNum, long count, const gxViewPort portList[]);
extern void		GXStShapeToFSSpec(gxShape source, FSSpec* spec, OSType creator, OSType fileType, ScriptCode script);
extern gxShape	GXStFSSpecToShape(FSSpec* spec, long count, const gxViewPort portList[]);
extern Handle	GXStFontToHandle(gxFont fontID, long glyphBits[]);
extern gxFont	GXStHandleToFont(Handle source);

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#ifdef __cplusplus
}
#endif

#endif /* __STORAGELIBRARY__ */
